==> blesta-5.10.2.zip: blesta/language/tr_tr/admin_company_currencies.php <==
<?php
/**
 * Admin Company Currencies
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyCurrencies.edit.confirm_edit'] = 'Bu para birimini güncellemek istediğinizden emin misiniz? Döviz kurları sistemde otomatik olarak güncellendiğinde bu para biriminin döviz kurunun üzerine yazılacaktır. Otomatik güncellemeleri [Ayarlar] > [Şirket] > [Para Birimleri] > [Para Birimi Kurulumu] altından devre dışı bırakabilirsiniz.';
$lang['AdminCompanyCurrencies.edit.field_editsubmit'] = 'Para Birimini Düzenle';
$lang['AdminCompanyCurrencies.edit.field_exchange_rate'] = 'Döviz Kuru';
$lang['AdminCompanyCurrencies.edit.field_suffix'] = 'Sonek Sembolü';
$lang['AdminCompanyCurrencies.edit.field_prefix'] = 'Önek Sembolü';
$lang['AdminCompanyCurrencies.edit.field_precision'] = 'Hassasiyet';
$lang['AdminCompanyCurrencies.edit.field_format'] = 'Biçim';
$lang['AdminCompanyCurrencies.edit.field_code'] = 'Para Birimi Kodu (ISO 4217)';
$lang['AdminCompanyCurrencies.edit.boxtitle_edit'] = 'Para Birimini Düzenle';
$lang['AdminCompanyCurrencies.edit.page_title'] = 'Ayarlar > Şirket > Para Birimleri > Para Birimini Düzenle';
$lang['AdminCompanyCurrencies.add.confirm_add'] = 'Bu para birimini oluşturmak istediğinizden emin misiniz? Döviz kurları sistemde otomatik olarak güncellendiğinde bu para biriminin döviz kurunun üzerine yazılacaktır. Otomatik güncellemeleri [Ayarlar] > [Şirket] > [Para Birimleri] > [Para Birimi Kurulumu] altından devre dışı bırakabilirsiniz.';
$lang['AdminCompanyCurrencies.add.field_addsubmit'] = 'Para Birimi Oluştur';
$lang['AdminCompanyCurrencies.add.field_exchange_rate'] = 'Döviz Kuru';
$lang['AdminCompanyCurrencies.add.field_suffix'] = 'Sonek Sembolü';
$lang['AdminCompanyCurrencies.add.field_prefix'] = 'Önek Sembolü';
$lang['AdminCompanyCurrencies.add.field_precision'] = 'Hassasiyet';
$lang['AdminCompanyCurrencies.add.field_format'] = 'Biçim';
$lang['AdminCompanyCurrencies.add.field_code'] = 'Para Birimi Kodu (ISO 4217)';
$lang['AdminCompanyCurrencies.add.boxtitle_add'] = 'Para Birimi Ekle';
$lang['AdminCompanyCurrencies.add.page_title'] = 'Ayarlar > Şirket > Para Birimleri > Para Birimi Ekle';
$lang['AdminCompanyCurrencies.active.no_exchange_updated'] = 'Asla';
$lang['AdminCompanyCurrencies.active.confirm_delete'] = 'Bu para birimini silmek istediğinizden emin misiniz?';
$lang['AdminCompanyCurrencies.active.option_delete'] = 'Silme';
$lang['AdminCompanyCurrencies.active.option_edit'] = 'Düzenle';
$lang['AdminCompanyCurrencies.active.text_options'] = 'Seçenekler';
$lang['AdminCompanyCurrencies.active.text_exchange_updated'] = 'Son Güncelleme';
$lang['AdminCompanyCurrencies.active.text_exchange_rate'] = 'Döviz Kuru';
$lang['AdminCompanyCurrencies.active.text_precision'] = 'Hassasiyet';
$lang['AdminCompanyCurrencies.active.text_format'] = 'Biçim';
$lang['AdminCompanyCurrencies.active.text_currency_code'] = 'Para Birimi Kodu (ISO 4217)';
$lang['AdminCompanyCurrencies.active.no_results'] = 'Aktif para birimi yoktur.';
$lang['AdminCompanyCurrencies.active.categorylink_addcurrency'] = 'Para Birimi Ekle';
$lang['AdminCompanyCurrencies.active.boxtitle_active'] = 'Aktif Para Birimleri';
$lang['AdminCompanyCurrencies.active.page_title'] = 'Ayarlar > Şirket > Para Birimleri > Aktif Para Birimleri';
$lang['AdminCompanyCurrencies.setup.closed_parenthesis'] = ')';
$lang['AdminCompanyCurrencies.setup.open_parenthesis'] = '(';
$lang['AdminCompanyCurrencies.setup.no_exchange_updated'] = 'Asla';
$lang['AdminCompanyCurrencies.setup.field.setupsubmit'] = 'Ayarları Güncelle';
$lang['AdminCompanyCurrencies.setup.field.exchange_rates_padding'] = 'Ped Döviz Kurları';
$lang['AdminCompanyCurrencies.setup.field.exchange_rates_processor_key'] = 'Döviz Kurları İşlemcisi API Anahtarı';
$lang['AdminCompanyCurrencies.setup.field.exchange_rates_processor'] = 'Döviz Kurları İşlemcisi';
$lang['AdminCompanyCurrencies.setup.field.last_updated'] = 'Son Güncellenen Fiyatlar';
$lang['AdminCompanyCurrencies.setup.field.exchange_rates_auto_update'] = 'Döviz Kurlarını Otomatik Olarak Güncelle';
$lang['AdminCompanyCurrencies.setup.field.multi_currency_pricing'] = 'Yalnızca Yeni Hizmetler için Paket Fiyatlandırmayı Kullanın';
$lang['AdminCompanyCurrencies.setup.heading_multicurrency'] = 'Çoklu Para Birimi';
$lang['AdminCompanyCurrencies.setup.field.client_set_currency'] = 'Müşterinin Para Birimi Ayarlamasına İzin Ver';
$lang['AdminCompanyCurrencies.setup.field.show_currency_code'] = 'Para Birimi Kodunu Göster';
$lang['AdminCompanyCurrencies.setup.field.default_currency'] = 'Varsayılan Para Birimi';
$lang['AdminCompanyCurrencies.setup.heading_general'] = 'Genel';
$lang['AdminCompanyCurrencies.setup.boxtitle_setup'] = 'Para Birimi Kurulumu';
$lang['AdminCompanyCurrencies.setup.tooltip_currency_pricing'] = 'Bu seçenek, yeni hizmetlerin oluşturulabilmesi için paket fiyatlandırmasının belirtilen para biriminde ayarlanmasını gerektirir. İşaretlenmemişse ve para birimi için paket fiyatlandırması mevcut değilse, fiyat varsayılan para birimindeki döviz kuruna göre hesaplanacaktır.

Yenileme hizmetleri her zaman seçilen para biriminde paket fiyatlandırmasını tercih eder, ancak paket için belirtilmemişse varsayılan para birimindeki döviz kurunu kullanır.';
$lang['AdminCompanyCurrencies.setup.page_title'] = 'Ayarlar > Şirket > Para Birimleri > Para Birimi Kurulumu';
$lang['AdminCompanyCurrencies.!cancel.field_cancel'] = 'İptal';
$lang['AdminCompanyCurrencies.!tooltip.exchange_rates_padding'] = 'Bir işlemci tarafından belirlenen döviz kuru değerleri verilen yüzde kadar artırılacaktır.';
$lang['AdminCompanyCurrencies.!tooltip.exchange_rates_processor_key'] = 'Seçilen işlemciden döviz kurlarını almak için bir API Anahtarı gereklidir.';
$lang['AdminCompanyCurrencies.!tooltip.exchange_rates_processor'] = 'Döviz kurlarını güncellemek için kullanılacak işlemciyi ayarlar. Kullanılabilir para birimleri işlemciye göre değişir.';
$lang['AdminCompanyCurrencies.!tooltip.exchange_rates_auto_update'] = 'Döviz kurlarının mevcut döviz kuru işlemcilerinden biri kullanılarak otomatik olarak güncellenmesine izin vermek için işaretleyin.';
$lang['AdminCompanyCurrencies.!tooltip.multi_currency_pricing'] = 'Paketlerin yalnızca o paket için tanımlanan fiyatlandırma kullanılarak sipariş edilmesine izin vermek için işaretleyin. Bunun işaretlenmesi, söz konusu paket için kabul etmek istediğiniz her para birimi için fiyatlandırmanın tanımlanmasını gerektirir. Başka bir deyişle, bu, para birimi dönüştürmenin gerçekleşmesini önler.';
$lang['AdminCompanyCurrencies.!tooltip.client_set_currency'] = 'Müşterilerin sistemde mevcut olanlar arasından kendi varsayılan para birimlerini seçmelerine izin vermek için işaretleyin.';
$lang['AdminCompanyCurrencies.!tooltip.show_currency_code'] = 'Görüntülenen fiyatların yanında para birimi kodunun görüntülenmesini etkinleştirmek için işaretleyin';
$lang['AdminCompanyCurrencies.!tooltip.default_currency'] = 'Sistemde kullanılan varsayılan para birimi. Bunu en çok tercih ettiğiniz para birimine ayarlayın.';
$lang['AdminCompanyCurrencies.!tooltip.precision'] = 'Hassasiyet, para biriminin desteklediği ondalık basamaktan sonraki anlamlı basamak sayısıdır.';
$lang['AdminCompanyCurrencies.!success.rates_updated'] = 'Döviz kurları başarıyla güncellenmiştir.';
$lang['AdminCompanyCurrencies.!success.delete_deleted'] = '1$s para birimi başarıyla silindi!';
$lang['AdminCompanyCurrencies.!success.edit_updated'] = '1$s para birimi başarıyla güncellendi!';
$lang['AdminCompanyCurrencies.!success.add_created'] = '1$s para birimi başarıyla oluşturuldu!';
$lang['AdminCompanyCurrencies.!success.setup_updated'] = 'Para Birimi Kurulumu ayarları başarıyla güncellendi!';

==> blesta-5.11.4.zip: blesta/language/tr_tr/admin_company_currencies.php <==
<?php
/**
 * Admin Company Currencies
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyCurrencies.edit.confirm_edit'] = 'Bu para birimini güncellemek istediğinizden emin misiniz? Döviz kurları sistemde otomatik olarak güncellendiğinde bu para biriminin döviz kurunun üzerine yazılacaktır. Otomatik güncellemeleri [Ayarlar] > [Şirket] > [Para Birimleri] > [Para Birimi Kurulumu] altından devre dışı bırakabilirsiniz.';
$lang['AdminCompanyCurrencies.edit.field_editsubmit'] = 'Para Birimini Düzenle';
$lang['AdminCompanyCurrencies.edit.field_exchange_rate'] = 'Döviz Kuru';
$lang['AdminCompanyCurrencies.edit.field_suffix'] = 'Sonek Sembolü';
$lang['AdminCompanyCurrencies.edit.field_prefix'] = 'Önek Sembolü';
$lang['AdminCompanyCurrencies.edit.field_precision'] = 'Hassasiyet';
$lang['AdminCompanyCurrencies.edit.field_format'] = 'Biçim';
$lang['AdminCompanyCurrencies.edit.field_code'] = 'Para Birimi Kodu (ISO 4217)';
$lang['AdminCompanyCurrencies.edit.boxtitle_edit'] = 'Para Birimini Düzenle';
$lang['AdminCompanyCurrencies.edit.page_title'] = 'Ayarlar > Şirket > Para Birimleri > Para Birimini Düzenle';
$lang['AdminCompanyCurrencies.add.confirm_add'] = 'Bu para birimini oluşturmak istediğinizden emin misiniz? Döviz kurları sistemde otomatik olarak güncellendiğinde bu para biriminin döviz kurunun üzerine yazılacaktır. Otomatik güncellemeleri [Ayarlar] > [Şirket] > [Para Birimleri] > [Para Birimi Kurulumu] altından devre dışı bırakabilirsiniz.';
$lang['AdminCompanyCurrencies.add.field_addsubmit'] = 'Para Birimi Oluştur';
$lang['AdminCompanyCurrencies.add.field_exchange_rate'] = 'Döviz Kuru';
$lang['AdminCompanyCurrencies.add.field_suffix'] = 'Sonek Sembolü';
$lang['AdminCompanyCurrencies.add.field_prefix'] = 'Önek Sembolü';
$lang['AdminCompanyCurrencies.add.field_precision'] = 'Hassasiyet';
$lang['AdminCompanyCurrencies.add.field_format'] = 'Biçim';
$lang['AdminCompanyCurrencies.add.field_code'] = 'Para Birimi Kodu (ISO 4217)';
$lang['AdminCompanyCurrencies.add.boxtitle_add'] = 'Para Birimi Ekle';
$lang['AdminCompanyCurrencies.add.page_title'] = 'Ayarlar > Şirket > Para Birimleri > Para Birimi Ekle';
$lang['AdminCompanyCurrencies.active.no_exchange_updated'] = 'Asla';
$lang['AdminCompanyCurrencies.active.confirm_delete'] = 'Bu para birimini silmek istediğinizden emin misiniz?';
$lang['AdminCompanyCurrencies.active.option_delete'] = 'Silme';
$lang['AdminCompanyCurrencies.active.option_edit'] = 'Düzenle';
$lang['AdminCompanyCurrencies.active.text_options'] = 'Seçenekler';
$lang['AdminCompanyCurrencies.active.text_exchange_updated'] = 'Son Güncelleme';
$lang['AdminCompanyCurrencies.active.text_exchange_rate'] = 'Döviz Kuru';
$lang['AdminCompanyCurrencies.active.text_precision'] = 'Hassasiyet';
$lang['AdminCompanyCurrencies.active.text_format'] = 'Biçim';
$lang['AdminCompanyCurrencies.active.text_currency_code'] = 'Para Birimi Kodu (ISO 4217)';
$lang['AdminCompanyCurrencies.active.no_results'] = 'Aktif para birimi yoktur.';
$lang['AdminCompanyCurrencies.active.categorylink_addcurrency'] = 'Para Birimi Ekle';
$lang['AdminCompanyCurrencies.active.boxtitle_active'] = 'Aktif Para Birimleri';
$lang['AdminCompanyCurrencies.active.page_title'] = 'Ayarlar > Şirket > Para Birimleri > Aktif Para Birimleri';
$lang['AdminCompanyCurrencies.setup.closed_parenthesis'] = ')';
$lang['AdminCompanyCurrencies.setup.open_parenthesis'] = '(';
$lang['AdminCompanyCurrencies.setup.no_exchange_updated'] = 'Asla';
$lang['AdminCompanyCurrencies.setup.field.setupsubmit'] = 'Ayarları Güncelle';
$lang['AdminCompanyCurrencies.setup.field.exchange_rates_padding'] = 'Ped Döviz Kurları';
$lang['AdminCompanyCurrencies.setup.field.exchange_rates_processor_key'] = 'Döviz Kurları İşlemcisi API Anahtarı';
$lang['AdminCompanyCurrencies.setup.field.exchange_rates_processor'] = 'Döviz Kurları İşlemcisi';
$lang['AdminCompanyCurrencies.setup.field.last_updated'] = 'Son Güncellenen Fiyatlar';
$lang['AdminCompanyCurrencies.setup.field.exchange_rates_auto_update'] = 'Döviz Kurlarını Otomatik Olarak Güncelle';
$lang['AdminCompanyCurrencies.setup.field.multi_currency_pricing'] = 'Yalnızca Yeni Hizmetler için Paket Fiyatlandırmayı Kullanın';
$lang['AdminCompanyCurrencies.setup.heading_multicurrency'] = 'Çoklu Para Birimi';
$lang['AdminCompanyCurrencies.setup.field.client_set_currency'] = 'Müşterinin Para Birimi Ayarlamasına İzin Ver';
$lang['AdminCompanyCurrencies.setup.field.show_currency_code'] = 'Para Birimi Kodunu Göster';
$lang['AdminCompanyCurrencies.setup.field.default_currency'] = 'Varsayılan Para Birimi';
$lang['AdminCompanyCurrencies.setup.heading_general'] = 'Genel';
$lang['AdminCompanyCurrencies.setup.boxtitle_setup'] = 'Para Birimi Kurulumu';
$lang['AdminCompanyCurrencies.setup.tooltip_currency_pricing'] = 'Bu seçenek, yeni hizmetlerin oluşturulabilmesi için paket fiyatlandırmasının belirtilen para biriminde ayarlanmasını gerektirir. İşaretlenmemişse ve para birimi için paket fiyatlandırması mevcut değilse, fiyat varsayılan para birimindeki döviz kuruna göre hesaplanacaktır.

Yenileme hizmetleri her zaman seçilen para biriminde paket fiyatlandırmasını tercih eder, ancak paket için belirtilmemişse varsayılan para birimindeki döviz kurunu kullanır.';
$lang['AdminCompanyCurrencies.setup.page_title'] = 'Ayarlar > Şirket > Para Birimleri > Para Birimi Kurulumu';
$lang['AdminCompanyCurrencies.!cancel.field_cancel'] = 'İptal';
$lang['AdminCompanyCurrencies.!tooltip.exchange_rates_padding'] = 'Bir işlemci tarafından belirlenen döviz kuru değerleri verilen yüzde kadar artırılacaktır.';
$lang['AdminCompanyCurrencies.!tooltip.exchange_rates_processor_key'] = 'Seçilen işlemciden döviz kurlarını almak için bir API Anahtarı gereklidir.';
$lang['AdminCompanyCurrencies.!tooltip.exchange_rates_processor'] = 'Döviz kurlarını güncellemek için kullanılacak işlemciyi ayarlar. Kullanılabilir para birimleri işlemciye göre değişir.';
$lang['AdminCompanyCurrencies.!tooltip.exchange_rates_auto_update'] = 'Döviz kurlarının mevcut döviz kuru işlemcilerinden biri kullanılarak otomatik olarak güncellenmesine izin vermek için işaretleyin.';
$lang['AdminCompanyCurrencies.!tooltip.multi_currency_pricing'] = 'Paketlerin yalnızca o paket için tanımlanan fiyatlandırma kullanılarak sipariş edilmesine izin vermek için işaretleyin. Bunun işaretlenmesi, söz konusu paket için kabul etmek istediğiniz her para birimi için fiyatlandırmanın tanımlanmasını gerektirir. Başka bir deyişle, bu, para birimi dönüştürmenin gerçekleşmesini önler.';
$lang['AdminCompanyCurrencies.!tooltip.client_set_currency'] = 'Müşterilerin sistemde mevcut olanlar arasından kendi varsayılan para birimlerini seçmelerine izin vermek için işaretleyin.';
$lang['AdminCompanyCurrencies.!tooltip.show_currency_code'] = 'Görüntülenen fiyatların yanında para birimi kodunun görüntülenmesini etkinleştirmek için işaretleyin';
$lang['AdminCompanyCurrencies.!tooltip.default_currency'] = 'Sistemde kullanılan varsayılan para birimi. Bunu en çok tercih ettiğiniz para birimine ayarlayın.';
$lang['AdminCompanyCurrencies.!tooltip.precision'] = 'Hassasiyet, para biriminin desteklediği ondalık basamaktan sonraki anlamlı basamak sayısıdır.';
$lang['AdminCompanyCurrencies.!success.rates_updated'] = 'Döviz kurları başarıyla güncellenmiştir.';
$lang['AdminCompanyCurrencies.!success.setup_updated'] = 'Para Birimi Kurulumu ayarları başarıyla güncellendi!';
$lang['AdminCompanyCurrencies.!success.delete_deleted'] = '%1$s para birimi başarıyla silindi!';
$lang['AdminCompanyCurrencies.!success.edit_updated'] = '%1$s para birimi başarıyla güncellendi!';
$lang['AdminCompanyCurrencies.!success.add_created'] = '%1$s para birimi başarıyla oluşturuldu!';
